==> seedsui-react-5.7.43.tgz: package/lib/Ellipsis/Ellipsis.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }
var _excluded = ["rows", "toggleProps", "html", "children"],
  _excluded2 = ["visible", "expandText", "collapseText", "style", "className"];
function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }
function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(arg) { var key = _toPrimitive(arg, "string"); return _typeof(key) === "symbol" ? key : String(key); }
function _toPrimitive(input, hint) { if (_typeof(input) !== "object" || input === null) return input; var prim = input[Symbol.toPrimitive]; if (prim !== undefined) { var res = prim.call(input, hint || "default"); if (_typeof(res) !== "object") return res; throw new TypeError("@@toPrimitive must return a primitive value."); } return (hint === "string" ? String : Number)(input); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useImperativeHandle, useRef, useEffect } from 'react';
import locale from "./../locale";
import { jsx as _jsx } from "react/jsx-runtime";
import { Fragment as _Fragment } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var TOGGLE_EXPAND_TEXT = locale('展开', 'expand');
var TOGGLE_COLLAPSE_TEXT = locale('收缩', 'collapse');
var Ellipsis = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$rows = _ref.rows,
    rows = _ref$rows === void 0 ? 3 : _ref$rows,
    _ref$toggleProps = _ref.toggleProps,
    toggleProps = _ref$toggleProps === void 0 ? {
      visible: true,
      expandText: TOGGLE_EXPAND_TEXT,
      collapseText: TOGGLE_COLLAPSE_TEXT
    } : _ref$toggleProps,
    html = _ref.html,
    children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded);
  // 展开和收缩样式
  var visible = toggleProps.visible,
    expandText = toggleProps.expandText,
    collapseText = toggleProps.collapseText,
    style = toggleProps.style,
    className = toggleProps.className,
    otherToggleProps = _objectWithoutProperties(toggleProps, _excluded2);

  // 只读时超过三行显示展开和收缩
  var contentRef = useRef(null);
  var toggleRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      getContentDOM: function getContentDOM() {
        return contentRef.current;
      },
      getToggleDOM: function getToggleDOM() {
        return toggleRef.current;
      }
    };
  });
  useEffect(function () {
    if (toggleRef.current && contentRef.current) {
      // 滚动高度和容器高度不一致说明有更多
      if (Math.abs(contentRef.current.scrollHeight - contentRef.current.clientHeight) > 2) {
        toggleRef.current.innerHTML = expandText || TOGGLE_EXPAND_TEXT;
        toggleRef.current.style.display = 'inline-block';
      }
    }
  }, [contentRef]); // eslint-disable-line

  function handleToggle(e) {
    var visible = contentRef.current.classList.contains("nowrap".concat(rows));
    if (visible) {
      contentRef.current.classList.remove("nowrap".concat(rows));
      if (toggleRef.current) toggleRef.current.innerHTML = collapseText || TOGGLE_COLLAPSE_TEXT;
    } else {
      contentRef.current.classList.add("nowrap".concat(rows));
      if (toggleRef.current) toggleRef.current.innerHTML = expandText || TOGGLE_EXPAND_TEXT;
    }
    e.stopPropagation();
  }
  return /*#__PURE__*/_jsxs(_Fragment, {
    children: [/*#__PURE__*/_jsx("div", _objectSpread(_objectSpread({
      ref: contentRef,
      className: "nowrap".concat(rows)
    }, props), {}, {
      dangerouslySetInnerHTML: html && typeof html === 'string' ? {
        __html: html
      } : null,
      children: children
    })), visible && /*#__PURE__*/_jsx("span", _objectSpread(_objectSpread({
      ref: toggleRef
    }, otherToggleProps), {}, {
      style: Object.assign({}, style, {
        display: 'none'
      }),
      className: "color-link".concat(className ? ' ' + className : ''),
      onClick: handleToggle
    }))]
  });
});
export default Ellipsis;

==> seedsui-react-5.8.10.tgz: package/lib/Ellipsis/Ellipsis.js <==
var _excluded = ["rows", "toggleProps", "html", "children"],
  _excluded2 = ["visible", "expandText", "collapseText", "style", "className"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useImperativeHandle, useRef, useEffect } from 'react';
import locale from "./../locale";
var TOGGLE_EXPAND_TEXT = locale('展开', 'expand');
var TOGGLE_COLLAPSE_TEXT = locale('收缩', 'collapse');
var Ellipsis = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var _ref$rows = _ref.rows,
    rows = _ref$rows === void 0 ? 3 : _ref$rows,
    _ref$toggleProps = _ref.toggleProps,
    toggleProps = _ref$toggleProps === void 0 ? {
      visible: true,
      expandText: TOGGLE_EXPAND_TEXT,
      collapseText: TOGGLE_COLLAPSE_TEXT
    } : _ref$toggleProps,
    html = _ref.html,
    children = _ref.children,
    props = _objectWithoutProperties(_ref, _excluded);
  // 展开和收缩样式
  var visible = toggleProps.visible,
    expandText = toggleProps.expandText,
    collapseText = toggleProps.collapseText,
    style = toggleProps.style,
    className = toggleProps.className,
    otherToggleProps = _objectWithoutProperties(toggleProps, _excluded2);

  // 只读时超过三行显示展开和收缩
  var contentRef = useRef(null);
  var toggleRef = useRef(null);
  useImperativeHandle(ref, function () {
    return {
      getContentDOM: function getContentDOM() {
        return contentRef.current;
      },
      getToggleDOM: function getToggleDOM() {
        return toggleRef.current;
      }
    };
  });
  useEffect(function () {
    if (toggleRef.current && contentRef.current) {
      // 滚动高度和容器高度不一致说明有更多
      if (Math.abs(contentRef.current.scrollHeight - contentRef.current.clientHeight) > 2) {
        toggleRef.current.innerHTML = expandText || TOGGLE_EXPAND_TEXT;
        toggleRef.current.style.display = 'inline-block';
      }
    }
  }, [contentRef]); // eslint-disable-line

  function handleToggle(e) {
    var visible = contentRef.current.classList.contains("nowrap".concat(rows));
    if (visible) {
      contentRef.current.classList.remove("nowrap".concat(rows));
      if (toggleRef.current) toggleRef.current.innerHTML = collapseText || TOGGLE_COLLAPSE_TEXT;
    } else {
      contentRef.current.classList.add("nowrap".concat(rows));
      if (toggleRef.current) toggleRef.current.innerHTML = expandText || TOGGLE_EXPAND_TEXT;
    }
    e.stopPropagation();
  }
  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", _extends({
    ref: contentRef,
    className: "nowrap".concat(rows)
  }, props, {
    dangerouslySetInnerHTML: html && typeof html === 'string' ? {
      __html: html
    } : null
  }), children), visible && /*#__PURE__*/React.createElement("span", _extends({
    ref: toggleRef
  }, otherToggleProps, {
    style: Object.assign({}, style, {
      display: 'none'
    }),
    className: "color-link".concat(className ? ' ' + className : ''),
    onClick: handleToggle
  })));
});
export default Ellipsis;
